@@ -66,15 +66,16 @@ class AlgorithmDaemon:
 
     def __send(self, *args):
         logger.info('Sending message: {}'.format(
-                '-'.join([msg for msg in args if msg])))
+            '-'.join([msg for msg in args if msg])))
         messages = []
         messages.extend([x.encode() for x in args])
-        try
+        try:
             self.__zmq_client.send_multipart(messages)
         except zmq.ZMQError as e:
             if e.errno == zmq.EAGAIN:
-                logger.warn(f'occur eagain erro, wait 1 seconds, and try sending again. {str(e)}')
-                sleep(1)
+                logger.warn(
+                    f'occur eagain erro, wait 1 seconds, and try sending again. {str(e)}')
+                time.sleep(1)
                 self.__zmq_client.send_multipart(messages)
 
     def __send_status(self, message=''):
